@@ -561,14 +561,16 @@ class Tio2Jira:
             # the asset UUIDs and store a list of the unique tag pairs for each.
             # In order to make this simple for Jira, we will be smashing the
             # category and value together and storing the uniques.
+            trans_list = self.config['tenable'].get('tio_transform_tags', list())
+            acache = self._asset_cache
             for asset in live:
                 # if the asset doesn't exist in the tag cache, then we will
                 # create the entry and store an empty list.
-                if asset['id'] not in self._asset_cache:
-                    self._asset_cache[asset['id']] = dict(tags=list())
+                if asset['id'] not in acache:
+                    acache[asset['id']] = dict(tags=list())
 
                 for a in self.config['tenable'].get('tio_asset_attr_cache', list()):
-                    self._asset_cache[asset['id']][a] = asset.get(a)
+                    acache[asset['id']][a] = asset.get(a)
 
                 # iterate over the tags
                 for tag in asset['tags']:
@@ -579,9 +581,14 @@ class Tio2Jira:
                     )
 
                     # If the tag name isn't in the cached list, then add it.
-                    if tag_name not in self._asset_cache[asset['id']]['tags']:
-                        self._asset_cache[asset['id']]['tags'].append(tag_name)
+                    if tag_name not in acache[asset['id']]['tags']:
+                        acache[asset['id']]['tags'].append(tag_name)
 
+                    # If the tag category is in the list of transformable tags,
+                    # we will then also convert it into a asset attribute for
+                    # use as a custom field.
+                    if tag['key'] in trans_list:
+                        acache[asset['id']][tag['key']] = tag['value']
 
             # generate a an export for the open and reopened vulns that match
             # the criticality rating described.  Then pass the export iterator
@@ -590,22 +597,26 @@ class Tio2Jira:
             if self.config['tenable'].get('tio_vpr_thresh'):
                 vpr = {'gte': self.config['tenable'].get('tio_vpr_thresh')}
             vulns = self._src.exports.vulns(
+                include_unlicensed=True,
                 last_found=observed_since,
                 severity=self.config['tenable']['tio_severities'],
                 num_assets=self.config['tenable'].get('chunk_size', 1000),
                 vpr=vpr,
                 tags=tags
             )
+            self._log.info('Updating and creating issues marked as Open')
             self.create_issues(vulns)
 
             # generate a an export for the fixed vulns that match the
             # criticality rating described.  Then pass the export iterator to
             # the close_issues method.
             closed = self._src.exports.vulns(
+                include_unlicensed=True,
                 last_fixed=observed_since,
                 state=['fixed'],
                 severity=self.config['tenable']['tio_severities'],
                 num_assets=self.config['tenable'].get('chunk_size', 1000))
+            self._log.info('Closing Issues Marked as Fixed.')
             self.close_issues(closed)
 
             # If any assets were terminated or deleted, we will then want to
